@@ -364,24 +364,26 @@ class WordType(caching.base.CachingMixin,models.Model):
     def get_celex_info(self):
         if self.Extra is None:
             self.Extra = {}
-        info = get_lexical_info(self.Label)
-        try:
-            self.Extra['CelexCategory'] = info['Cat']
-        except KeyError:
-            self.Extra['CelexCategory'] = 'NA'
-        try:
-            self.Extra['CelexFrequency'] = info['Freq']
-        except KeyError:
-            self.Extra['CelexFrequency'] = 'NA'
-        try:
-            self.Extra['CelexNeighDen'],self.Extra['CelexFWND'] = info['ND'], info['FWND']
-        except KeyError:
-            self.Extra['CelexNeighDen'],self.Extra['CelexFWND'] = 'NA','NA'
-        try:
-            self.Extra['CelexSPhoneProb'],self.Extra['CelexBiPhoneProb'] = info['SP'],info['BP']
-        except KeyError:
-            self.Extra['CelexSPhoneProb'],self.Extra['CelexBiPhoneProb'] = 'NA','NA'
-        self.save()
+        if 'CelexCategory' not in self.Extra:
+            info = get_lexical_info(self.Label)
+            try:
+                self.Extra['CelexCategory'] = info['Cat']
+            except KeyError:
+                self.Extra['CelexCategory'] = 'NA'
+            try:
+                self.Extra['CelexFrequency'] = info['Freq']
+            except KeyError:
+                self.Extra['CelexFrequency'] = 'NA'
+            try:
+                self.Extra['CelexNeighDen'],self.Extra['CelexFWND'] = info['ND'], info['FWND']
+            except KeyError:
+                self.Extra['CelexNeighDen'],self.Extra['CelexFWND'] = 'NA','NA'
+            try:
+                self.Extra['CelexSPhoneProb'],self.Extra['CelexBiPhoneProb'] = info['SP'],info['BP']
+            except KeyError:
+                self.Extra['CelexSPhoneProb'],self.Extra['CelexBiPhoneProb'] = 'NA','NA'
+            self.save()
+        return self.Extra
 
     def __unicode__(self):
         return u'%s' % self.Label
@@ -391,7 +393,7 @@ class WordType(caching.base.CachingMixin,models.Model):
             self.get_celex_info()
         if self.Extra['CelexCategory'] not in ['N','V','ADV','A']:
             return False
-        if sum([x.Vowel for x in self.UR.all()]) < 2:
+        if self.get_syllable_count() < 2:
             return False
         return True
 
@@ -442,12 +444,8 @@ class WordType(caching.base.CachingMixin,models.Model):
         self.save()
         return self.CVSkel
 
-    def getNumSylls(self):
-        numSylls = 0
-        for seg in self.UR.all():
-            if seg.isSyllabic():
-                numSylls += 1
-        return numSylls
+    def get_syllable_count(self):
+        return sum([x.isSyllabic() for x in self.UR.all()])
 
     def getNumVows(self):
         numVows = 0
@@ -619,6 +617,9 @@ class WordToken(caching.base.CachingMixin,models.Model):
 
     objects = caching.base.CachingManager()
 
+    class Meta:
+        ordering = ['Dialog','DialogPart','Begin']
+
     def __unicode__(self):
         return u'%s' % unicode(self.WordType)
 
@@ -681,10 +682,9 @@ class WordToken(caching.base.CachingMixin,models.Model):
         if style == 'A' and window == 'A':
             self.PrevSemPred = sp
             self.save()
-            return self.PrevSemPred
         return sp
 
-    def getFollSemPred(self,style='A',window='A'):
+    def getFollSemPred(self,style='A',window='A',disambiguate=True):
         if style == 'A' and window == 'A':
             if self.FollSemPred is not None:
                 return self.FollSemPred
@@ -700,7 +700,6 @@ class WordToken(caching.base.CachingMixin,models.Model):
         if style == 'A' and window == 'A':
             self.FollSemPred = sp
             self.save()
-            return self.FollSemPred
         return sp
 
     def setStrFormants(self,formants=None):
@@ -856,12 +855,8 @@ class WordToken(caching.base.CachingMixin,models.Model):
                 diagPlace += lengthOfA
         return diagPlace
 
-    def getNumSylls(self):
-        numSylls = 0
-        for seg in self.SR.all():
-            if seg.isSyllabic():
-                numSylls += 1
-        return numSylls
+    def get_syllable_count(self):
+        return sum([x.isSyllabic for x in self.SR.all()])
 
     def getDuration(self):
         return self.End - self.Begin
@@ -899,7 +894,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
 
     def getPreviousSpeakingRate(self):
         prev_context = self.getPreviousContext()
-        total_syllables = float(sum([x.getNumSylls() for x in prev_context]))
+        total_syllables = float(sum([x.get_syllable_count() for x in prev_context]))
         total_seconds = self.getPrevDistToPause()
         if total_seconds != 0.0:
             rate = total_syllables / total_seconds
@@ -909,7 +904,7 @@ class WordToken(caching.base.CachingMixin,models.Model):
 
     def getFollowingSpeakingRate(self):
         foll_context = self.getFollowingContext()
-        total_syllables = float(sum([x.getNumSylls() for x in foll_context]))
+        total_syllables = float(sum([x.get_syllable_count() for x in foll_context]))
         total_seconds = self.getFollDistToPause()
         if total_seconds != 0.0:
             rate = total_syllables / total_seconds
@@ -1062,14 +1057,9 @@ class WordToken(caching.base.CachingMixin,models.Model):
                     outline['wasRepeated'] = 'True'
                 else:
                     outline['wasRepeated'] = 'False'
+        celex_info = self.WordType.get_celex_info()
         if 'CelexCategory' not in outline:
-            cat = lookupCat(self.WordType.Label)
-            outline['CelexCategory'] = cat
-        if outline['CelexCategory'] not in ['N','ADV','A','V']:
-            return None
-
-        if 'C' in form['lexical_scale']:
-            celex_info = get_lexical_info(self.WordType.Label)
+            outline['CelexCategory'] = celex_info['Cat']
 
         if 'B' in form['category']:
             if 'BuckeyeCategory' not in outline:
@@ -1176,14 +1166,19 @@ class WordToken(caching.base.CachingMixin,models.Model):
 
         for w in eval(form['sem_pred_window']):
             for s in eval(form['sem_pred_style']):
-                if form['prev_sem_pred']:
-                    label = '%sWindowPrev%sSemPred' %(w,s)
-                    if label not in outline:
-                        outline[label] = self.getPrevSemPred(window = w,style=s)
-                if form['foll_sem_pred']:
-                    label = '%sWindowFoll%sSemPred' %(w,s)
-                    if label not in outline:
-                        outline[label] = self.getFollSemPred(window = w,style=s)
+                for d in eval(form['sense_options']):
+                    if d == 'Disambiguate':
+                        dcheck = True
+                    else:
+                        dcheck = False
+                    if form['prev_sem_pred']:
+                        label = '%s%sWindowPrev%sSemPred' %(d,w,s)
+                        if label not in outline:
+                            outline[label] = self.getPrevSemPred(window = w,style=s,disambiguate=dcheck)
+                    if form['foll_sem_pred']:
+                        label = '%s%sWindowFoll%sSemPred' %(d,w,s)
+                        if label not in outline:
+                            outline[label] = self.getFollSemPred(window = w,style=s,disambiguate=ddcheck)
         if form['pause_dist']:
             if 'DistFollPause' not in outline:
                 outline['DistFollPause'] = self.getFollDistToPause()
